# Roadmap

[0.0.1] Version

- add model_name routing
- add embedding reranker routing
- add CLI supporting with --server server1_url server2_url server3_rul --max-load 11 22 33
- build pypi package [beta]
